@@ -2,5 +2,5 @@ import smllib.sml
 from smllib.builder import SmlObjBuilder
 
 
-class SmlGetListResponseBuilder(SmlObjBuilder):
+class SmlGetListResponseBuilder(SmlObjBuilder[smllib.sml.SmlGetListResponse]):
     BUILDS = smllib.sml.SmlGetListResponse
