@@ -2,9 +2,9 @@ from smllib.builder import SmlObjBuilder
 from smllib.sml import SmlCloseResponse, SmlOpenResponse
 
 
-class SmlOpenResponseBuilder(SmlObjBuilder):
+class SmlOpenResponseBuilder(SmlObjBuilder[SmlOpenResponse]):
     BUILDS = SmlOpenResponse
 
 
-class SmlCloseResponseBuilder(SmlObjBuilder):
+class SmlCloseResponseBuilder(SmlObjBuilder[SmlCloseResponse]):
     BUILDS = SmlCloseResponse
